<?php
/**
 * 添加自定义辅助函数
 */

if (!function_exists('config_path')) {
    /**
     * Get the configuration path.
     *
     * @param string $path
     * @return string
     */
    function config_path($path = '')
    {
        return app()->basePath() . '/config' . ($path ? '/' . $path : $path);
    }
}
/**
 * 参数签名校验
 * @param array $params
 * @return string
 */
function generateSign(array $params, $secret_key)
{
    unset($params['sign']);
    // 将删除参数组中所有等值为FALSE的参数（包括：NULL, 空字符串，0， false）
    // $params = array_filter($params);

    // 按照键名对参数数组进行升序排序
    ksort($params);

    // 给参数数组追加密钥，键名为 key， 值为签名配置中配置的 secret_key 的值
    $params['chxq_key'] = $secret_key;
    \Illuminate\Support\Facades\Log::debug($params);
    // 生成 URL-encode 之后的请求字符串
    $str = http_build_query($params);
    $str = urldecode($str);
    \Illuminate\Support\Facades\Log::debug($str);
    //$str = "address=计算机啊手机壳阿看见手机卡&address_type=1&area_id=2&area_name=西安市&city_id=2&city_name=西安市&contact_mobile
    //=18458881890&contact_name=刘德华&province_id=1&province_name=陕西省&uid=0&zipcode=1000000";
    // 将请求字符串使用MD5加密后，再转换成大写，并返回
    return strtoupper(MD5($str));
}

/**
 * 验证签名
 * @param $sign
 * @param $params
 * @return bool
 */
function verifySign($sign, $params, $secret_key)
{
    if ($sign == generateSign($params, $secret_key)) {
        return true;
    } else {
        return false;
    };

}

function http($url, $param, $method = 'post')
{
    try {
        $client = new \GuzzleHttp\Client();
        $response = $client->request($method, $url, $param);
        $result = json_decode($response->getBody()->getContents(), true);
        \Illuminate\Support\Facades\Log::debug('url:' . $url . 'param:' . json_encode($param) . 'response:' . json_encode($result));
        if (isset($result['code']) && $result['code'] == 0) {
            return $result['data'];
        } else {
            return [];
        }
    } catch (\Exception $exception) {
        return [];
    }

}

function jsonSuccess($data = [], $msg = "成功", $extra = [])
{
    $response = array(
        'code' => 0,
        'msg' => $msg,
        'data' => []
    );
    if ($data) {
        if (is_array($data)) {
            //带有分页格式转换
            if (isset($data['meta'])) {
                // 更改元数据格式，全部包含在data下
                $temp = array(
                    'data' => array(
                        'data' => $data['data'],
                        'pagination' => $data['meta']['pagination']
                    )
                );
                if ($extra) {
                    $temp['data'] = array_merge($temp['data'], $extra);
                }
                $response = array_merge($response, $temp);
            } elseif (isset($data['data'])) {
                if ($extra) {
                    $data['data'] = array_merge($data['data'], $extra);
                }
                $response = array_merge($response, $data);
            } else {
                $temp = array(
                    'data' => $data
                );
                if ($extra) {
                    $temp['data'] = array_merge($temp['data'], $extra);
                }
                $response = array_merge($response, $temp);
            }
        } else {
            $response['data'] = $data;
        }
    }
    return $response;
}

function jsonError($msg)
{
    $response = array(
        'code' => 1,
        'msg' => $msg,
        'data' => ""
    );
    return $response;
}

function subtext($text, $length)
{
    if (mb_strlen($text, 'utf8') > $length) {
        return mb_substr($text, 0, $length - 1, 'utf8') . '...';
    } else {
        return $text;
    }
}

function success($data = [], $msg = "成功")
{
    $response = array(
        'code' => 0,
        'msg' => $msg,
        'data' => new stdClass()
    );
    if ($data) {
        if (is_array($data)) {
            //带有分页格式转换
            if (isset($data['meta'])) {
                // 更改元数据格式，全部包含在data下
                $temp = array(
                    'data' => array(
                        'data' => $data['data'],
                        'pagination' => $data['meta']['pagination']
                    )
                );
                $response = array_merge($response, $temp);
            } elseif (isset($data['data'])) {
                $response = $data;
            } else {
                $temp = array(
                    'data' => $data
                );
                $response = array_merge($response, $temp);
            }
        }
    }
    return $response;
}

//转换数字
function getNumber($number)
{
    if (empty($number) || !is_numeric($number)) return (string)intval($number);
    $unit = "";
    if ($number >= 10000) {
        $leftNumber = floor($number / 10000);
        $rightNumber = bcmul(($number % 10000) / 10000, '1', 1);
        $number = floatval($leftNumber + $rightNumber);
        $unit = "w";
    } else {
        $decimals = $number > 1 ? 2 : 6;
        $number = (float)number_format($number, $decimals, '.', '');
    }
    return (string)$number . $unit;
}

function getClientIp()
{
    $ip = '';
    $unknown = '';

    if (isset($_SERVER['HTTP_X_FORWARDED_FOR']) && $_SERVER['HTTP_X_FORWARDED_FOR'] && strcasecmp($_SERVER['HTTP_X_FORWARDED_FOR'], $unknown)) {
        // 使用透明代理、欺骗性代理的情况
        $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];

    } elseif (isset($_SERVER['REMOTE_ADDR']) && $_SERVER['REMOTE_ADDR'] && strcasecmp($_SERVER['REMOTE_ADDR'], $unknown)) {
        // 没有代理、使用普通匿名代理和高匿代理的情况
        $ip = $_SERVER['REMOTE_ADDR'];
    }

    // 处理多层代理的情况
    if (strpos($ip, ',') !== false) {
        // 输出第一个IP
        $ips = explode(',', $ip);
        $ip = $ips[0];
    }

    return $ip;
}

/**
 * 多维数组按单字段排序
 * @param $array
 * @param $field
 * @param bool $desc
 */
function sortArrByField(&$array, $field, $desc = false)
{
    $fieldArr = array();
    foreach ($array as $k => $v) {
        $fieldArr[$k] = $v[$field];
    }
    $sort = $desc == false ? SORT_ASC : SORT_DESC;
    array_multisort($fieldArr, $sort, $array);
}